Learn R Programming

simulist (version 0.7.0)

.add_missing: Introduce user-specified proportion of custom missing values into a <data.frame>

Description

Introduce user-specified proportion of custom missing values into a <data.frame>

Usage

.add_missing(linelist, .args)

Value

A line list <data.frame>

Arguments

linelist

Line list <data.frame> output from sim_linelist().

.args

A list of setting from messy_linelist().