<data.frame> defining either age-stratified hospitalisation or
death risk, or defining age structure of population is correctCheck if <data.frame> defining either age-stratified hospitalisation or
death risk, or defining age structure of population is correct
.check_df(x, df_type = c("risk", "age"), age_range = NULL)A <data.frame>, also called for error side-effects when input is
invalid.
A <data.frame>.
A character string, either "risk" or "age" to specify
which input <data.frame> is being checked.
A numeric vector of length 2. Only required when
df_type = risk, NULL by default.