sim_linelist()Check if R object is line list from sim_linelist()
.check_linelist(linelist)Invisibly return the linelist
<data.frame>. The function is
called for its side-effects, which will error if the input is invalid.
Line list <data.frame> output from sim_linelist().
This is a check that the object supplied to linelist is from the
sim_linelist() or sim_outbreak() functions, it is not related to
the class of the object, in other words, it does not check the object is
of class <linelist>.